@@ -40,7 +40,6 @@
 #include <gst/pbutils/pbutils.h>
 
 #include "rb-debug.h"
-#include "rb-marshal.h"
 #include "rb-util.h"
 
 #include "rb-player.h"
@@ -514,10 +513,10 @@ bus_cb (GstBus *bus, GstMessage *message, RBPlayerGst *mp)
 		if (emit) {
 			if (message_from_sink (mp->priv->audio_sink, message)) {
 				rb_debug ("got error from sink: %s (%s)", error->message, debug);
-				/* Translators: the parameter here is an error message */
 				g_set_error (&sig_error,
 					     RB_PLAYER_ERROR,
 					     code,
+					     /* Translators: the parameter here is an error message */
 					     _("Failed to open output device: %s"),
 					     error->message);
 			} else {
@@ -691,19 +690,9 @@ construct_pipeline (RBPlayerGst *mp, GError **error)
 	g_object_notify (G_OBJECT (mp), "playbin");
 	g_object_notify (G_OBJECT (mp), "bus");
 
-	/* Use gsettingsaudiosink for audio if there's no audio sink yet */
 	g_object_get (mp->priv->playbin, "audio-sink", &mp->priv->audio_sink, NULL);
 	if (mp->priv->audio_sink == NULL) {
-		const char *try_sinks[] = { "gsettingsaudiosink", "gconfaudiosink", "autoaudiosink" };
-		int i;
-
-		for (i = 0; i < G_N_ELEMENTS (try_sinks); i++) {
-			mp->priv->audio_sink = rb_player_gst_try_audio_sink (try_sinks[i], NULL);
-			if (mp->priv->audio_sink != NULL) {
-				g_object_set (mp->priv->playbin, "audio-sink", mp->priv->audio_sink, NULL);
-				break;
-			}
-		}
+		mp->priv->audio_sink = rb_player_gst_try_audio_sink ("autoaudiosink", NULL);
 		if (mp->priv->audio_sink == NULL) {
 			g_set_error (error,
 				     RB_PLAYER_ERROR,
@@ -712,6 +701,7 @@ construct_pipeline (RBPlayerGst *mp, GError **error)
 				     "autoaudiosink");
 			return FALSE;
 		}
+		g_object_set (mp->priv->playbin, "audio-sink", mp->priv->audio_sink, NULL);
 	} else {
 		rb_debug ("existing audio sink found");
 		g_object_unref (mp->priv->audio_sink);
@@ -1166,7 +1156,7 @@ rb_player_gst_class_init (RBPlayerGstClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerGstClass, prepare_source),
 			      NULL, NULL,
-			      rb_marshal_VOID__STRING_OBJECT,
+			      NULL,
 			      G_TYPE_NONE,
 			      2,
 			      G_TYPE_STRING, GST_TYPE_ELEMENT);
@@ -1176,7 +1166,7 @@ rb_player_gst_class_init (RBPlayerGstClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerGstClass, can_reuse_stream),
 			      NULL, NULL,
-			      rb_marshal_BOOLEAN__STRING_STRING_OBJECT,
+			      NULL,
 			      G_TYPE_BOOLEAN,
 			      3,
 			      G_TYPE_STRING, G_TYPE_STRING, GST_TYPE_ELEMENT);
@@ -1186,7 +1176,7 @@ rb_player_gst_class_init (RBPlayerGstClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (RBPlayerGstClass, reuse_stream),
 			      NULL, NULL,
-			      rb_marshal_VOID__STRING_STRING_OBJECT,
+			      NULL,
 			      G_TYPE_NONE,
 			      3,
 			      G_TYPE_STRING, G_TYPE_STRING, GST_TYPE_ELEMENT);
@@ -1196,7 +1186,7 @@ rb_player_gst_class_init (RBPlayerGstClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      0,	/* no point handling this internally */
 			      NULL, NULL,
-			      rb_marshal_VOID__POINTER_POINTER_POINTER,
+			      NULL,
 			      G_TYPE_NONE,
 			      3,
 			      G_TYPE_POINTER, G_TYPE_STRV, G_TYPE_STRV);
