@@ -1204,8 +1204,9 @@ impl_song_properties (RBSource *asource)
 }
 
 static void
-impl_get_status (RBDisplayPage *page, char **text, char **progress_text, float *progress)
+impl_get_status (RBDisplayPage *page, char **text, gboolean *busy)
 {
+	RBPodcastSource *source = RB_PODCAST_SOURCE (page);
 	RhythmDBQueryModel *query_model;
 
 	/* hack to get these strings marked for translation */
@@ -1218,15 +1219,17 @@ impl_get_status (RBDisplayPage *page, char **text, char **progress_text, float *
 		*text = rhythmdb_query_model_compute_status_normal (query_model,
 								    "%d episode",
 								    "%d episodes");
-		if (rhythmdb_query_model_has_pending_changes (query_model))
-			*progress = -1.0f;
-
 		g_object_unref (query_model);
-	} else {
-		*text = g_strdup ("");
 	}
+
+	g_object_get (source->priv->podcast_mgr, "updating", busy, NULL);
 }
 
+static void
+podcast_manager_updating_cb (GObject *obj, GParamSpec *pspec, gpointer data)
+{
+	rb_display_page_notify_status_changed (RB_DISPLAY_PAGE (data));
+}
 
 static char *
 impl_get_delete_label (RBSource *source)
@@ -1580,6 +1583,8 @@ impl_constructed (GObject *object)
 	g_object_unref (accel_group);
 	g_object_unref (shell);
 
+	g_signal_connect (source->priv->podcast_mgr, "notify::updating", G_CALLBACK (podcast_manager_updating_cb), source);
+
 	rb_podcast_source_do_query (source, TRUE);
 }
 
