@@ -30,9 +30,6 @@
 
 #include <glib/gi18n.h>
 
-#include <libpeas/peas.h>
-#include <libpeas-gtk/peas-gtk.h>
-
 #include <shell/rb-application.h>
 #include <shell/rb-shell.h>
 #include <lib/rb-debug.h>
@@ -129,66 +126,6 @@ quit_action_cb (GSimpleAction *action, GVariant *parameters, gpointer user_data)
 	rb_shell_quit (RB_SHELL (rb->priv->shell), NULL);
 }
 
-static gboolean
-plugins_window_delete_cb (GtkWidget *window,
-			  GdkEventAny *event,
-			  gpointer data)
-{
-	gtk_widget_hide (window);
-	return TRUE;
-}
-
-static void
-plugins_response_cb (GtkDialog *dialog,
-		     int response_id,
-		     gpointer data)
-{
-	if (response_id == GTK_RESPONSE_CLOSE)
-		gtk_widget_hide (GTK_WIDGET (dialog));
-}
-
-static void
-plugins_action_cb (GSimpleAction *action, GVariant *parameters, gpointer user_data)
-{
-	RBApplication *app = RB_APPLICATION (user_data);
-
-	if (app->priv->plugins == NULL) {
-		GtkWidget *content_area;
-		GtkWidget *manager;
-		GtkWindow *window;
-
-		g_object_get (app->priv->shell, "window", &window, NULL);
-
-		app->priv->plugins = gtk_dialog_new_with_buttons (_("Configure Plugins"),
-								  window,
-								  GTK_DIALOG_DESTROY_WITH_PARENT,
-								  _("_Close"),
-								  GTK_RESPONSE_CLOSE,
-								  NULL);
-		content_area = gtk_dialog_get_content_area (GTK_DIALOG (app->priv->plugins));
-		gtk_container_set_border_width (GTK_CONTAINER (app->priv->plugins), 5);
-		gtk_box_set_spacing (GTK_BOX (content_area), 2);
-
-		g_signal_connect_object (G_OBJECT (app->priv->plugins),
-					 "delete_event",
-					 G_CALLBACK (plugins_window_delete_cb),
-					 NULL, 0);
-		g_signal_connect_object (G_OBJECT (app->priv->plugins),
-					 "response",
-					 G_CALLBACK (plugins_response_cb),
-					 NULL, 0);
-
-		manager = peas_gtk_plugin_manager_new (NULL);
-		gtk_widget_show_all (GTK_WIDGET (manager));
-		gtk_box_pack_start (GTK_BOX (content_area), manager, TRUE, TRUE, 0);
-		gtk_window_set_default_size (GTK_WINDOW (app->priv->plugins), 600, 400);
-
-		g_object_unref (window);
-	}
-
-	gtk_window_present (GTK_WINDOW (app->priv->plugins));
-}
-
 static void
 preferences_action_cb (GSimpleAction *action, GVariant *parameters, gpointer user_data)
 {
@@ -260,7 +197,7 @@ about_action_cb (GSimpleAction *action, GVariant *parameters, gpointer user_data
 	g_object_get (app->priv->shell, "window", &window, NULL);
 	gtk_show_about_dialog (GTK_WINDOW (window),
 			       "version", VERSION,
-			       "copyright", "Copyright \xc2\xa9 2005 - 2016 The Rhythmbox authors\nCopyright \xc2\xa9 2003 - 2005 Colin Walters\nCopyright \xc2\xa9 2002, 2003 Jorn Baayen",
+			       "copyright", "Copyright \xc2\xa9 2005 - 2019 The Rhythmbox authors\nCopyright \xc2\xa9 2003 - 2005 Colin Walters\nCopyright \xc2\xa9 2002, 2003 Jorn Baayen",
 			       "license", license_trans,
 			       "website-label", _("Rhythmbox Website"),
 			       "website", "https://wiki.gnome.org/Apps/Rhythmbox",
@@ -352,7 +289,6 @@ static void
 impl_startup (GApplication *app)
 {
 	RBApplication *rb = RB_APPLICATION (app);
-	gboolean shell_shows_app_menu;
 	GtkBuilder *builder;
 	GMenuModel *menu;
 	GtkCssProvider *provider;
@@ -364,7 +300,6 @@ impl_startup (GApplication *app)
 		{ "activate-source", activate_source_action_cb, "(su)" },
 
 		/* app menu actions */
-		{ "plugins", plugins_action_cb },
 		{ "preferences", preferences_action_cb },
 		{ "help", help_action_cb },
 		{ "about", about_action_cb },
@@ -380,22 +315,11 @@ impl_startup (GApplication *app)
 					 G_N_ELEMENTS (app_actions),
 					 app);
 
-	g_object_get (gtk_settings_get_default (),
-		      "gtk-shell-shows-app-menu", &shell_shows_app_menu,
-		      NULL);
-
 	builder = rb_builder_load ("app-menu.ui", NULL);
 	menu = G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu"));
 	rb_application_link_shared_menus (rb, G_MENU (menu));
 	rb_application_add_shared_menu (rb, "app-menu", menu);
 
-	/* only set the app menu if the shell shows it; otherwise, we'll
-	 * stick a menu button in the toolbar.
-	 */
-	if (shell_shows_app_menu) {
-		gtk_application_set_app_menu (GTK_APPLICATION (app), menu);
-	}
-	
 	g_object_unref (builder);
 
 	/* Use our own css provider */
