@@ -937,11 +937,15 @@ rb_removable_media_manager_device_is_android (RBRemovableMediaManager *manager,
 
 	const char *androids[] = {
 		"Android",
-		"Nexus"
+		"Nexus",
+		"Pixel",
+		"Nexus_5X"
 	};
 	const char *android_vendors[] = {
 		"motorola",
-		"OnePlus"
+		"OnePlus",
+		"Google",
+		"bq"
 	};
 
 	match = FALSE;
