@@ -279,11 +279,18 @@ db_load_complete_cb (RhythmDB *db, RBLibrarySource *source)
 	RhythmDBImportJob *job;
 
 	/* once the database is loaded, we can run the query to populate the library source */
-	g_object_set (source, "populate", TRUE, NULL);
+	g_object_set (source,
+		      "populate", TRUE,
+		      "load-status", RB_SOURCE_LOAD_STATUS_LOADED,
+		      NULL);
 
 	if (source->priv->do_initial_import) {
 		const char *music_dir;
 		char *music_dir_uri;
+		const char *set_locations[2];
+
+		g_signal_handlers_block_by_func (source->priv->db_settings,
+						 G_CALLBACK (db_settings_changed_cb), source);
 		
 		music_dir = rb_music_dir ();
 		music_dir_uri = g_filename_to_uri (music_dir, NULL, NULL);
@@ -293,6 +300,13 @@ db_load_complete_cb (RhythmDB *db, RBLibrarySource *source)
 			g_mkdir_with_parents (music_dir, 0700);
 		}
 
+		set_locations[0] = music_dir_uri;
+		set_locations[1] = NULL;
+		g_settings_set_strv (source->priv->db_settings, "locations", set_locations);
+
+		g_signal_handlers_unblock_by_func (source->priv->db_settings,
+						   G_CALLBACK (db_settings_changed_cb), source);
+
 		/* import anything that's already in there */
 		job = maybe_create_import_job (source);
 		rhythmdb_import_job_add_uri (job, music_dir_uri);
@@ -344,22 +358,8 @@ rb_library_source_constructed (GObject *object)
 
 	/* Set up the default library location if there's no library location set */
 	locations = g_settings_get_strv (source->priv->db_settings, "locations");
-	if (g_strv_length (locations) == 0) {
-		char *music_dir_uri;
-
-		music_dir_uri = g_filename_to_uri (rb_music_dir (), NULL, NULL);
-		if (music_dir_uri != NULL) {
-			const char *set_locations[2];
-
-			set_locations[0] = music_dir_uri;
-			set_locations[1] = NULL;
-			g_settings_set_strv (source->priv->db_settings, "locations", set_locations);
-
-			source->priv->do_initial_import = TRUE;
-
-			g_free (music_dir_uri);
-		}
-	}
+	if (g_strv_length (locations) == 0)
+		source->priv->do_initial_import = TRUE;
 	g_strfreev (locations);
 
 	songs = rb_source_get_entry_view (RB_SOURCE (source));
@@ -385,6 +385,7 @@ rb_library_source_constructed (GObject *object)
 	g_object_set (source, "playlist-menu", playlist_add_menu, NULL);
 	g_object_unref (model);
 
+	rb_display_page_set_icon_name (RB_DISPLAY_PAGE (source), "folder-music-symbolic");
 	rb_library_source_sync_child_sources (source);
 
 	g_object_unref (shell);
@@ -415,11 +416,11 @@ rb_library_source_new (RBShell *shell)
 					  "name", _("Music"),
 					  "entry-type", RHYTHMDB_ENTRY_TYPE_SONG,
 					  "shell", shell,
+					  "load-status", RB_SOURCE_LOAD_STATUS_LOADING,
 					  "populate", FALSE,		/* wait until the database is loaded */
 					  "toolbar-menu", toolbar,
 					  "settings", g_settings_get_child (settings, "source"),
 					  NULL));
-	rb_display_page_set_icon_name (RB_DISPLAY_PAGE (source), "folder-music-symbolic");
 	g_object_unref (settings);
 	g_object_unref (builder);
 
