@@ -498,19 +498,17 @@ rb_media_player_source_get_entries (RBMediaPlayerSource *source,
  * @source: the #RBMediaPlayerSource
  * @entries: (element-type RB.RhythmDBEntry) (transfer full): list of entries to delete
  * @callback: callback to call on completion
- * @data: (closure) (scope notified): data for callback
- * @destroy_data: callback to free the callback data
+ * @data: data for callback
  */
 void
 rb_media_player_source_delete_entries	(RBMediaPlayerSource *source,
 					 GList *entries,
-					 RBMediaPlayerSourceDeleteCallback callback,
-					 gpointer data,
-					 GDestroyNotify destroy_data)
+					 GAsyncReadyCallback callback,
+					 gpointer data)
 {
 	RBMediaPlayerSourceClass *klass = RB_MEDIA_PLAYER_SOURCE_GET_CLASS (source);
 
-	klass->delete_entries (source, entries, callback, data, destroy_data);
+	klass->delete_entries (source, entries, callback, data);
 }
 
 static void
@@ -598,7 +596,7 @@ rb_media_player_source_show_properties (RBMediaPlayerSource *source)
 
 	/* create sync UI */
 	container = GTK_CONTAINER (gtk_builder_get_object (builder, "sync-settings-ui-container"));
-	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (container), rb_sync_settings_ui_new (source, priv->sync_settings));
+	gtk_container_add (container, rb_sync_settings_ui_new (source, priv->sync_settings));
 
 	container = GTK_CONTAINER (gtk_builder_get_object (builder, "sync-state-ui-container"));
 	gtk_box_pack_start (GTK_BOX (container), rb_sync_state_ui_new (priv->sync_state), TRUE, TRUE, 0);
@@ -755,8 +753,9 @@ transfer_batch_cancelled_cb (RBTrackTransferBatch *batch, RBMediaPlayerSource *s
 
 
 static void
-sync_delete_done_cb (RBMediaPlayerSource *source, gpointer dontcare)
+sync_delete_done_cb (GObject *source_object, GAsyncResult *result, gpointer data)
 {
+	RBMediaPlayerSource *source = RB_MEDIA_PLAYER_SOURCE (source_object);
 	RBMediaPlayerSourcePrivate *priv = MEDIA_PLAYER_SOURCE_GET_PRIVATE (source);
 	rb_debug ("finished deleting %d files from media player", priv->sync_state->sync_remove_count);
 
@@ -920,7 +919,7 @@ display_sync_settings_dialog (RBMediaPlayerSource *source)
 	priv->sync_dialog_error_box = GTK_WIDGET (gtk_builder_get_object (builder, "sync-dialog-message"));
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "sync-settings-ui-container"));
-	gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (widget), rb_sync_settings_ui_new (source, priv->sync_settings));
+	gtk_container_add (GTK_CONTAINER (widget), rb_sync_settings_ui_new (source, priv->sync_settings));
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "sync-state-ui-container"));
 	gtk_box_pack_start (GTK_BOX (widget), rb_sync_state_ui_new (priv->sync_state), TRUE, TRUE, 0);
@@ -955,8 +954,7 @@ sync_idle_delete_entries (RBMediaPlayerSource *source)
 	rb_debug ("deleting %d files from media player", priv->sync_state->sync_remove_count);
 	rb_media_player_source_delete_entries (source,
 					       priv->sync_state->sync_to_remove,
-					       (RBMediaPlayerSourceDeleteCallback) sync_delete_done_cb,
-					       NULL,
+					       sync_delete_done_cb,
 					       NULL);
 	return FALSE;
 }
