@@ -68,7 +68,7 @@ static void rb_missing_files_source_get_property (GObject *object,
 static RBEntryView *impl_get_entry_view (RBSource *source);
 static void impl_song_properties (RBSource *source);
 static void impl_delete_selected (RBSource *source);
-static void impl_get_status (RBDisplayPage *page, char **text, char **progress_text, float *progress);
+static void impl_get_status (RBDisplayPage *page, char **text, gboolean *busy);
 
 static void rb_missing_files_source_songs_show_popup_cb (RBEntryView *view,
 							 gboolean over_entry,
@@ -123,8 +123,6 @@ static void
 rb_missing_files_source_init (RBMissingFilesSource *source)
 {
 	source->priv = G_TYPE_INSTANCE_GET_PRIVATE (source, RB_TYPE_MISSING_FILES_SOURCE, RBMissingFilesSourcePrivate);
-
-	rb_display_page_set_icon_name (RB_DISPLAY_PAGE (source), "dialog-warning-symbolic");
 }
 
 static void
@@ -195,6 +193,8 @@ rb_missing_files_source_constructed (GObject *object)
 
 	g_object_set (source, "query-model", model, NULL);
 	g_object_unref (model);
+
+	rb_display_page_set_icon_name (RB_DISPLAY_PAGE (source), "dialog-warning-symbolic");
 }
 
 static void
@@ -350,7 +350,7 @@ rb_missing_files_source_songs_sort_order_changed_cb (GObject *object,
 }
 
 static void
-impl_get_status (RBDisplayPage *page, char **text, char **progress_text, float *progress)
+impl_get_status (RBDisplayPage *page, char **text, gboolean *busy)
 {
 	RhythmDBQueryModel *model;
 	gint count;
