@@ -58,7 +58,7 @@ static void rb_source_get_property (GObject *object,
 					GValue *value,
 					GParamSpec *pspec);
 
-static void default_get_status (RBDisplayPage *page, char **text, char **progress_text, float *progress);
+static void default_get_status (RBDisplayPage *page, char **text, gboolean *busy);
 static void default_activate (RBDisplayPage *page);
 static GList *default_get_property_views (RBSource *source);
 static gboolean default_can_rename (RBSource *source);
@@ -71,6 +71,7 @@ static void default_add_to_queue (RBSource *source, RBSource *queue);
 static void default_move_to_trash (RBSource *source);
 static char *default_get_delete_label (RBSource *source);
 
+static void rb_source_status_changed_cb (RBDisplayPage *page);
 static void rb_source_post_entry_deleted_cb (GtkTreeModel *model,
 					     RhythmDBEntry *entry,
 					     RBSource *source);
@@ -107,6 +108,7 @@ struct _RBSourcePrivate
 	guint hidden_when_empty : 1;
 	guint update_visibility_id;
 	guint update_status_id;
+	guint status_changed_idle_id;
 	RhythmDBEntryType *entry_type;
 	RBSourceLoadStatus load_status;
 
@@ -154,6 +156,7 @@ rb_source_class_init (RBSourceClass *klass)
 
 	page_class->activate = default_activate;
 	page_class->get_status = default_get_status;
+	page_class->status_changed = rb_source_status_changed_cb;
 
 	klass->reset_filters = default_reset_filters;
 	klass->get_property_views = default_get_property_views;
@@ -386,6 +389,10 @@ rb_source_dispose (GObject *object)
 		g_source_remove (source->priv->update_status_id);
 		source->priv->update_status_id = 0;
 	}
+	if (source->priv->status_changed_idle_id != 0) {
+		g_source_remove (source->priv->status_changed_idle_id);
+		source->priv->status_changed_idle_id = 0;
+	}
 
 	g_clear_object (&source->priv->settings);
 	g_clear_object (&source->priv->toolbar_menu);
@@ -513,6 +520,7 @@ rb_source_set_property (GObject *object,
 		break;
 	case PROP_LOAD_STATUS:
 		source->priv->load_status = g_value_get_enum (value);
+		rb_display_page_notify_status_changed (RB_DISPLAY_PAGE (source));
 		break;
 	case PROP_TOOLBAR_MENU:
 		source->priv->toolbar_menu = g_value_dup_object (value);
@@ -586,10 +594,11 @@ default_activate (RBDisplayPage *page)
 static void
 default_get_status (RBDisplayPage *page,
 		    char **text,
-		    char **progress_text,
-		    float *progress)
+		    gboolean *busy)
 {
 	RBSource *source = RB_SOURCE (page);
+	RBSourceLoadStatus status;
+
 	/* hack to get these strings marked for translation */
 	if (0) {
 		ngettext ("%d song", "%d songs", 0);
@@ -599,11 +608,16 @@ default_get_status (RBDisplayPage *page,
 		*text = rhythmdb_query_model_compute_status_normal (source->priv->query_model,
 								    "%d song",
 								    "%d songs");
-		if (rhythmdb_query_model_has_pending_changes (source->priv->query_model)) {
-			*progress = -1.0f;
-		}
-	} else {
-		*text = g_strdup ("");
+	}
+
+	g_object_get (source, "load-status", &status, NULL);
+	switch (status) {
+	case RB_SOURCE_LOAD_STATUS_WAITING:
+	case RB_SOURCE_LOAD_STATUS_LOADING:
+		*busy = TRUE;
+		break;
+	default:
+		break;
 	}
 }
 
@@ -1486,6 +1500,33 @@ rb_source_get_playback_status (RBSource *source, char **text, float *progress)
 		klass->get_playback_status (source, text, progress);
 }
 
+static gboolean
+status_changed_idle_cb (RBSource *source)
+{
+	RBEntryView *entry_view;
+	char *status = NULL;
+	gboolean busy = FALSE;
+
+	rb_display_page_get_status (RB_DISPLAY_PAGE (source), &status, &busy);
+
+	entry_view = rb_source_get_entry_view (source);
+	if (entry_view != NULL)
+		rb_entry_view_set_status (entry_view, status, busy);
+
+	g_free (status);
+	source->priv->status_changed_idle_id = 0;
+	return FALSE;
+}
+
+static void
+rb_source_status_changed_cb (RBDisplayPage *page)
+{
+	RBSource *source = RB_SOURCE (page);
+	if (source->priv->status_changed_idle_id == 0) {
+		source->priv->status_changed_idle_id =
+			g_idle_add ((GSourceFunc) status_changed_idle_cb, source);
+	}
+}
 
 /* This should really be standard. */
 #define ENUM_ENTRY(NAME, DESC) { NAME, "" #NAME "", DESC }
