@@ -104,14 +104,11 @@ main (int argc, char **argv)
 	RhythmDBEntry *entry;
 
 	gtk_init (&argc, &argv);
-	gdk_threads_init ();
 	rb_thread_helpers_init ();
 	rb_file_helpers_init (TRUE);
 	rb_stock_icons_init ();
 	rb_debug_init (TRUE);
 
-	GDK_THREADS_ENTER ();
-
 	db = rhythmdb_tree_new ("test");
 
 	rhythmdb_write_lock (db);
@@ -149,7 +146,6 @@ main (int argc, char **argv)
 	
 	rhythmdb_shutdown (db);
 	g_object_unref (G_OBJECT (db));
-	GDK_THREADS_LEAVE ();
 	
 	exit (0);
 }
